/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataMongodbatlasFlexSnapshotsConfig extends cdktf.TerraformMetaArguments {
    /**
    * Human-readable label that identifies the flex cluster whose snapshot you want to restore.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.36.0/docs/data-sources/flex_snapshots#name DataMongodbatlasFlexSnapshots#name}
    */
    readonly name: string;
    /**
    * Unique 24-hexadecimal digit string that identifies your project. Use the [/groups](#tag/Projects/operation/listProjects) endpoint to retrieve all projects to which the authenticated user has access.
    *
    * **NOTE**: Groups and projects are synonymous terms. Your group id is the same as your project id. For existing groups, your group/project id remains the same. The resource and corresponding endpoints use the term groups.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.36.0/docs/data-sources/flex_snapshots#project_id DataMongodbatlasFlexSnapshots#project_id}
    */
    readonly projectId: string;
}
export interface DataMongodbatlasFlexSnapshotsResults {
}
export declare function dataMongodbatlasFlexSnapshotsResultsToTerraform(struct?: DataMongodbatlasFlexSnapshotsResults): any;
export declare function dataMongodbatlasFlexSnapshotsResultsToHclTerraform(struct?: DataMongodbatlasFlexSnapshotsResults): any;
export declare class DataMongodbatlasFlexSnapshotsResultsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataMongodbatlasFlexSnapshotsResults | undefined;
    set internalValue(value: DataMongodbatlasFlexSnapshotsResults | undefined);
    get expiration(): string;
    get finishTime(): string;
    get mongoDbVersion(): string;
    get name(): string;
    get projectId(): string;
    get scheduledTime(): string;
    get snapshotId(): string;
    get startTime(): string;
    get status(): string;
}
export declare class DataMongodbatlasFlexSnapshotsResultsList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataMongodbatlasFlexSnapshotsResultsOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.36.0/docs/data-sources/flex_snapshots mongodbatlas_flex_snapshots}
*/
export declare class DataMongodbatlasFlexSnapshots extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "mongodbatlas_flex_snapshots";
    /**
    * Generates CDKTF code for importing a DataMongodbatlasFlexSnapshots resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataMongodbatlasFlexSnapshots to import
    * @param importFromId The id of the existing DataMongodbatlasFlexSnapshots that should be imported. Refer to the {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.36.0/docs/data-sources/flex_snapshots#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataMongodbatlasFlexSnapshots to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/mongodb/mongodbatlas/1.36.0/docs/data-sources/flex_snapshots mongodbatlas_flex_snapshots} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataMongodbatlasFlexSnapshotsConfig
    */
    constructor(scope: Construct, id: string, config: DataMongodbatlasFlexSnapshotsConfig);
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _projectId?;
    get projectId(): string;
    set projectId(value: string);
    get projectIdInput(): string | undefined;
    private _results;
    get results(): DataMongodbatlasFlexSnapshotsResultsList;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
